# PaperTrailActor Actor Model
# @author ToanDP <toandptech@gmail.com>
module PaperTrailActor
  class Actor < ActiveRecord::Base
    self.table_name = PaperTrailActor::Constants::ACTOR_TABLE_NAME
    cattr_accessor :current_user, :current_request, :controller_name, :action_name

    before_validation :build_actor

    # Private methods
    private

    def build_actor
      self.controller_name = controller_name
      self.action_name = action_name

      if current_request.present?
        self.current_url = current_request.url
        self.request_method = current_request.method.upcase
        self.ip = current_request.remote_ip
      end

      self.is_console = defined?(::Rails::Console) ? 'YES' : 'NO'
      self.employee_id = current_user if current_user.present?
      self.hostname = Socket.gethostname

      self.git_user = git_user_info
      self.git_email = git_email_info
      self.git_fingerprint = git_fingerprint_info
      self.git_ssh_key = git_ssh_key_info
    end

    def git_user_info
      Terrapin::CommandLine.new("git config --get user.name").run.strip
    rescue => e
      nil
    end

    def git_email_info
      Terrapin::CommandLine.new("git config --get user.email").run.strip
    rescue => e
      nil
    end

    def git_fingerprint_info
      id_rsa_path = File.read(File.expand_path(PaperTrailActor.configuration.ssh_id_rsa_path))
      ssh_key = SSHKey.new(id_rsa_path)
      ssh_key.fingerprint
    rescue => e
      nil
    end

    def git_ssh_key_info
      id_rsa_path = File.read(File.expand_path(PaperTrailActor.configuration.ssh_id_rsa_path))
      ssh_key = SSHKey.new(id_rsa_path)
      ssh_key.ssh_public_key
    rescue => e
      nil
    end
  end
end
