# PaperTrailActor Migration
# @author ToanDP <toandptech@gmail.com>

require "rails/generators"
require "rails/generators/active_record"

module PaperTrailActor
  class InstallGenerator < ::Rails::Generators::Base
    include ::Rails::Generators::Migration

    MYSQL_ADAPTERS = [
      "ActiveRecord::ConnectionAdapters::MysqlAdapter",
      "ActiveRecord::ConnectionAdapters::Mysql2Adapter"
    ].freeze

    class << self
      def next_migration_number(dirname)
        ::ActiveRecord::Generators::Base.next_migration_number(dirname)
      end
    end

    source_root File.expand_path("templates", __dir__)

    def copy_initializer_file
      copy_file "paper_trail_actor_config_template.rb", "config/initializers/paper_trail_actor.rb"
    end

    def create_migration_file
      migration_dir = File.expand_path("db/migrate")
      if self.class.migration_exists?(migration_dir, "create_paper_trail_actors")
        ::Kernel.warn "Migration already exists: create_paper_trail_actors"
      else
        migration_template(
          "paper_trail_actor_migration_template.rb",
          "db/migrate/create_paper_trail_actors.rb",
          actor_table_name: actor_table_name,
          migration_version: migration_version
        )
      end
    end

    def actor_table_name
      PaperTrailActor::Constants::ACTOR_TABLE_NAME
    end

    def migration_version
      major = ActiveRecord::VERSION::MAJOR
      if major >= 5
        "[#{major}.#{ActiveRecord::VERSION::MINOR}]"
      end
    end
  end
end
